# In Browser VSCode

Code Server is a packaging of VS Code in the browser. Within QHub we have packaged Code Server such that every user's
JupyterLab has a full-featured code editor. This editor will have access to all the same files that your regular
JupyterLab session has access to. To launch `Code Server` click on the `VS Code IDE` icon from the Launcher screen, see
below.

![QHub Kernel Selection](../images/qhub_kernel_selection.png)

A new VS Code tab will be opened, and from there you can access all of the same files as in your JupyterLab file
browser. The VS Code state will be saved between sessions so feel free to add extensions, plugins, etc. to enhance your
user experience.

![VSCode in browser](../images/qhub_vscode.png)
